==> DateTime-Locale-1.16.tar.gz: DateTime-Locale-1.16/share/se-NO.pl <==
{
  am_pm_abbreviated => [
    "i.b.",
    "e.b."
  ],
  available_formats => {
    E => "ccc",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-one" => "'week' W 'of' MMM",
    "MMMMW-count-other" => "'week' W 'of' MMM",
    "MMMMW-count-two" => "'week' W 'of' MMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-one" => "'week' w 'of' y",
    "yw-count-other" => "'week' w 'of' y",
    "yw-count-two" => "'week' w 'of' y"
  },
  code => "se-NO",
  date_format_full => "y MMMM d, EEEE",
  date_format_long => "y MMMM d",
  date_format_medium => "y MMM d",
  date_format_short => "y-MM-dd",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "vuos",
    "ma\N{U+014b}",
    "gask",
    "duor",
    "bear",
    "l\N{U+00e1}v",
    "sotn"
  ],
  day_format_narrow => [
    "V",
    "M",
    "G",
    "D",
    "B",
    "L",
    "S"
  ],
  day_format_wide => [
    "vuoss\N{U+00e1}rga",
    "ma\N{U+014b}\N{U+014b}eb\N{U+00e1}rga",
    "gaskavahkku",
    "duorasdat",
    "bearjadat",
    "l\N{U+00e1}vvardat",
    "sotnabeaivi"
  ],
  day_stand_alone_abbreviated => [
    "vuos",
    "ma\N{U+014b}",
    "gask",
    "duor",
    "bear",
    "l\N{U+00e1}v",
    "sotn"
  ],
  day_stand_alone_narrow => [
    "V",
    "M",
    "G",
    "D",
    "B",
    "L",
    "S"
  ],
  day_stand_alone_wide => [
    "vuoss\N{U+00e1}rga",
    "ma\N{U+014b}\N{U+014b}eb\N{U+00e1}rga",
    "gaskavahkku",
    "duorasdat",
    "bearjadat",
    "l\N{U+00e1}vvardat",
    "sotnabeaivi"
  ],
  era_abbreviated => [
    "o.Kr.",
    "m.Kr."
  ],
  era_narrow => [
    "o.Kr.",
    "m.Kr."
  ],
  era_wide => [
    "ovdal Kristtusa",
    "ma\N{U+014b}\N{U+014b}el Kristtusa"
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%A, %B %d. b. %Y %H:%M:%S %Z",
  glibc_date_format => "%Y-%m-%d",
  glibc_datetime_format => "%a, %b %e. b. %Y %T %Z",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Northern Sami",
  month_format_abbreviated => [
    "o\N{U+0111}\N{U+0111}j",
    "guov",
    "njuk",
    "cuo",
    "mies",
    "geas",
    "suoi",
    "borg",
    "\N{U+010d}ak\N{U+010d}",
    "golg",
    "sk\N{U+00e1}b",
    "juov"
  ],
  month_format_narrow => [
    "O",
    "G",
    "N",
    "C",
    "M",
    "G",
    "S",
    "B",
    "\N{U+010c}",
    "G",
    "S",
    "J"
  ],
  month_format_wide => [
    "o\N{U+0111}\N{U+0111}ajagem\N{U+00e1}nnu",
    "guovvam\N{U+00e1}nnu",
    "njuk\N{U+010d}am\N{U+00e1}nnu",
    "cuo\N{U+014b}om\N{U+00e1}nnu",
    "miessem\N{U+00e1}nnu",
    "geassem\N{U+00e1}nnu",
    "suoidnem\N{U+00e1}nnu",
    "borgem\N{U+00e1}nnu",
    "\N{U+010d}ak\N{U+010d}am\N{U+00e1}nnu",
    "golggotm\N{U+00e1}nnu",
    "sk\N{U+00e1}bmam\N{U+00e1}nnu",
    "juovlam\N{U+00e1}nnu"
  ],
  month_stand_alone_abbreviated => [
    "o\N{U+0111}\N{U+0111}j",
    "guov",
    "njuk",
    "cuo",
    "mies",
    "geas",
    "suoi",
    "borg",
    "\N{U+010d}ak\N{U+010d}",
    "golg",
    "sk\N{U+00e1}b",
    "juov"
  ],
  month_stand_alone_narrow => [
    "O",
    "G",
    "N",
    "C",
    "M",
    "G",
    "S",
    "B",
    "\N{U+010c}",
    "G",
    "S",
    "J"
  ],
  month_stand_alone_wide => [
    "o\N{U+0111}\N{U+0111}ajagem\N{U+00e1}nnu",
    "guovvam\N{U+00e1}nnu",
    "njuk\N{U+010d}am\N{U+00e1}nnu",
    "cuo\N{U+014b}om\N{U+00e1}nnu",
    "miessem\N{U+00e1}nnu",
    "geassem\N{U+00e1}nnu",
    "suoidnem\N{U+00e1}nnu",
    "borgem\N{U+00e1}nnu",
    "\N{U+010d}ak\N{U+010d}am\N{U+00e1}nnu",
    "golggotm\N{U+00e1}nnu",
    "sk\N{U+00e1}bmam\N{U+00e1}nnu",
    "juovlam\N{U+00e1}nnu"
  ],
  name => "Northern Sami Norway",
  native_language => "davvis\N{U+00e1}megiella",
  native_name => "davvis\N{U+00e1}megiella Norga",
  native_script => undef,
  native_territory => "Norga",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4"
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4"
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4"
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4"
  ],
  script => undef,
  territory => "Norway",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 31
}

==> DateTime-Locale-1.32.tar.gz: DateTime-Locale-1.32/share/se-NO.pl <==
{
  am_pm_abbreviated => [
    "i.b.",
    "e.b.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "se-NO",
  date_format_full => "y MMMM d, EEEE",
  date_format_long => "y MMMM d",
  date_format_medium => "y MMM d",
  date_format_short => "y-MM-dd",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "vuos",
    "ma\N{U+014b}",
    "gask",
    "duor",
    "bear",
    "l\N{U+00e1}v",
    "sotn",
  ],
  day_format_narrow => [
    "V",
    "M",
    "G",
    "D",
    "B",
    "L",
    "S",
  ],
  day_format_wide => [
    "vuoss\N{U+00e1}rga",
    "ma\N{U+014b}\N{U+014b}eb\N{U+00e1}rga",
    "gaskavahkku",
    "duorasdat",
    "bearjadat",
    "l\N{U+00e1}vvardat",
    "sotnabeaivi",
  ],
  day_stand_alone_abbreviated => [
    "vuos",
    "ma\N{U+014b}",
    "gask",
    "duor",
    "bear",
    "l\N{U+00e1}v",
    "sotn",
  ],
  day_stand_alone_narrow => [
    "V",
    "M",
    "G",
    "D",
    "B",
    "L",
    "S",
  ],
  day_stand_alone_wide => [
    "vuoss\N{U+00e1}rga",
    "ma\N{U+014b}\N{U+014b}eb\N{U+00e1}rga",
    "gaskavahkku",
    "duorasdat",
    "bearjadat",
    "l\N{U+00e1}vvardat",
    "sotnabeaivi",
  ],
  era_abbreviated => [
    "o.Kr.",
    "m.Kr.",
  ],
  era_narrow => [
    "o.Kr.",
    "m.Kr.",
  ],
  era_wide => [
    "ovdal Kristtusa",
    "ma\N{U+014b}\N{U+014b}el Kristtusa",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%A, %B %d. b. %Y %H:%M:%S %Z",
  glibc_date_format => "%Y-%m-%d",
  glibc_datetime_format => "%a, %b %e. b. %Y %T %Z",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Northern Sami",
  month_format_abbreviated => [
    "o\N{U+0111}\N{U+0111}j",
    "guov",
    "njuk",
    "cuo",
    "mies",
    "geas",
    "suoi",
    "borg",
    "\N{U+010d}ak\N{U+010d}",
    "golg",
    "sk\N{U+00e1}b",
    "juov",
  ],
  month_format_narrow => [
    "O",
    "G",
    "N",
    "C",
    "M",
    "G",
    "S",
    "B",
    "\N{U+010c}",
    "G",
    "S",
    "J",
  ],
  month_format_wide => [
    "o\N{U+0111}\N{U+0111}ajagem\N{U+00e1}nnu",
    "guovvam\N{U+00e1}nnu",
    "njuk\N{U+010d}am\N{U+00e1}nnu",
    "cuo\N{U+014b}om\N{U+00e1}nnu",
    "miessem\N{U+00e1}nnu",
    "geassem\N{U+00e1}nnu",
    "suoidnem\N{U+00e1}nnu",
    "borgem\N{U+00e1}nnu",
    "\N{U+010d}ak\N{U+010d}am\N{U+00e1}nnu",
    "golggotm\N{U+00e1}nnu",
    "sk\N{U+00e1}bmam\N{U+00e1}nnu",
    "juovlam\N{U+00e1}nnu",
  ],
  month_stand_alone_abbreviated => [
    "o\N{U+0111}\N{U+0111}j",
    "guov",
    "njuk",
    "cuo",
    "mies",
    "geas",
    "suoi",
    "borg",
    "\N{U+010d}ak\N{U+010d}",
    "golg",
    "sk\N{U+00e1}b",
    "juov",
  ],
  month_stand_alone_narrow => [
    "O",
    "G",
    "N",
    "C",
    "M",
    "G",
    "S",
    "B",
    "\N{U+010c}",
    "G",
    "S",
    "J",
  ],
  month_stand_alone_wide => [
    "o\N{U+0111}\N{U+0111}ajagem\N{U+00e1}nnu",
    "guovvam\N{U+00e1}nnu",
    "njuk\N{U+010d}am\N{U+00e1}nnu",
    "cuo\N{U+014b}om\N{U+00e1}nnu",
    "miessem\N{U+00e1}nnu",
    "geassem\N{U+00e1}nnu",
    "suoidnem\N{U+00e1}nnu",
    "borgem\N{U+00e1}nnu",
    "\N{U+010d}ak\N{U+010d}am\N{U+00e1}nnu",
    "golggotm\N{U+00e1}nnu",
    "sk\N{U+00e1}bmam\N{U+00e1}nnu",
    "juovlam\N{U+00e1}nnu",
  ],
  name => "Northern Sami Norway",
  native_language => "davvis\N{U+00e1}megiella",
  native_name => "davvis\N{U+00e1}megiella Norga",
  native_script => undef,
  native_territory => "Norga",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  script => undef,
  territory => "Norway",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 39,
}
